@@ -30,6 +30,13 @@ pub mod cosmos {
         }
     }
 
+    /// Authorization of secondary accounts and transactions.
+    pub mod authz {
+        pub mod v1beta1 {
+            include!("prost/cosmos.authz.v1beta1.rs");
+        }
+    }
+
     /// Balances.
     pub mod bank {
         pub mod v1beta1 {
@@ -68,6 +75,9 @@ pub mod cosmos {
             pub mod v1beta1 {
                 include!("prost/cosmos.base.reflection.v1beta1.rs");
             }
+            pub mod v2alpha1 {
+                include!("prost/cosmos.base.reflection.v2alpha1.rs");
+            }
         }
 
         /// Snapshots containing Tendermint state sync info.
@@ -95,6 +105,13 @@ pub mod cosmos {
         }
     }
 
+    // Module capabilities
+    pub mod capability {
+        pub mod v1beta1 {
+            include!("prost/cosmos.capability.v1beta1.rs");
+        }
+    }
+
     /// Crisis handling
     pub mod crisis {
         pub mod v1beta1 {
@@ -117,6 +134,9 @@ pub mod cosmos {
         pub mod secp256k1 {
             include!("prost/cosmos.crypto.secp256k1.rs");
         }
+        pub mod secp256r1 {
+            include!("prost/cosmos.crypto.secp256r1.rs");
+        }
     }
 
     /// Messages and services handling token distribution
@@ -225,6 +245,9 @@ pub mod ibc {
             pub mod v1 {
                 include!("prost/ibc.applications.transfer.v1.rs");
             }
+            pub mod v2 {
+                include!("prost/ibc.applications.transfer.v2.rs");
+            }
         }
     }
 
@@ -277,6 +300,9 @@ pub mod ibc {
             pub mod v1 {
                 include!("prost/ibc.lightclients.solomachine.v1.rs");
             }
+            pub mod v2 {
+                include!("prost/ibc.lightclients.solomachine.v2.rs");
+            }
         }
         pub mod tendermint {
             pub mod v1 {
