@@ -1,3 +1,20 @@
+/// GenericAuthorization gives the grantee unrestricted permissions to execute
+/// the provided method on behalf of the granter's account.
+#[derive(Clone, PartialEq, ::prost::Message)]
+pub struct GenericAuthorization {
+    /// Msg, identified by it's type URL, to grant unrestricted permissions to execute
+    #[prost(string, tag="1")]
+    pub msg: ::prost::alloc::string::String,
+}
+/// Grant gives permissions to execute
+/// the provide method with expiration time.
+#[derive(Clone, PartialEq, ::prost::Message)]
+pub struct Grant {
+    #[prost(message, optional, tag="1")]
+    pub authorization: ::core::option::Option<::prost_types::Any>,
+    #[prost(message, optional, tag="2")]
+    pub expiration: ::core::option::Option<::prost_types::Timestamp>,
+}
 /// EventGrant is emitted on Msg/Grant
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct EventGrant {
@@ -24,27 +41,13 @@ pub struct EventRevoke {
     #[prost(string, tag="4")]
     pub grantee: ::prost::alloc::string::String,
 }
-/// GenericAuthorization gives the grantee unrestricted permissions to execute
-/// the provided method on behalf of the granter's account.
+/// GenesisState defines the authz module's genesis state.
 #[derive(Clone, PartialEq, ::prost::Message)]
-pub struct GenericAuthorization {
-    /// Msg, identified by it's type URL, to grant unrestricted permissions to execute
-    #[prost(string, tag="1")]
-    pub msg: ::prost::alloc::string::String,
+pub struct GenesisState {
+    #[prost(message, repeated, tag="1")]
+    pub authorization: ::prost::alloc::vec::Vec<GrantAuthorization>,
 }
-/// Grant gives permissions to execute
-/// the provide method with expiration time.
-#[derive(Clone, PartialEq, ::prost::Message)]
-pub struct Grant {
-    #[prost(message, optional, tag="1")]
-    pub authorization: ::core::option::Option<::prost_types::Any>,
-    #[prost(message, optional, tag="2")]
-    pub expiration: ::core::option::Option<::prost_types::Timestamp>,
-}
-/// GrantAuthorization extends a grant with both the addresses of the grantee and granter.
-/// It is used in genesis.proto and query.proto
-///
-/// Since: cosmos-sdk 0.45.2
+/// GrantAuthorization defines the GenesisState/GrantAuthorization type.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct GrantAuthorization {
     #[prost(string, tag="1")]
@@ -56,6 +59,116 @@ pub struct GrantAuthorization {
     #[prost(message, optional, tag="4")]
     pub expiration: ::core::option::Option<::prost_types::Timestamp>,
 }
+/// QueryGrantsRequest is the request type for the Query/Grants RPC method.
+#[derive(Clone, PartialEq, ::prost::Message)]
+pub struct QueryGrantsRequest {
+    #[prost(string, tag="1")]
+    pub granter: ::prost::alloc::string::String,
+    #[prost(string, tag="2")]
+    pub grantee: ::prost::alloc::string::String,
+    /// Optional, msg_type_url, when set, will query only grants matching given msg type.
+    #[prost(string, tag="3")]
+    pub msg_type_url: ::prost::alloc::string::String,
+    /// pagination defines an pagination for the request.
+    #[prost(message, optional, tag="4")]
+    pub pagination: ::core::option::Option<super::super::base::query::v1beta1::PageRequest>,
+}
+/// QueryGrantsResponse is the response type for the Query/Authorizations RPC method.
+#[derive(Clone, PartialEq, ::prost::Message)]
+pub struct QueryGrantsResponse {
+    /// authorizations is a list of grants granted for grantee by granter.
+    #[prost(message, repeated, tag="1")]
+    pub grants: ::prost::alloc::vec::Vec<Grant>,
+    /// pagination defines an pagination for the response.
+    #[prost(message, optional, tag="2")]
+    pub pagination: ::core::option::Option<super::super::base::query::v1beta1::PageResponse>,
+}
+/// Generated client implementations.
+pub mod query_client {
+    #![allow(unused_variables, dead_code, missing_docs, clippy::let_unit_value)]
+    use tonic::codegen::*;
+    /// Query defines the gRPC querier service.
+    #[derive(Debug, Clone)]
+    pub struct QueryClient<T> {
+        inner: tonic::client::Grpc<T>,
+    }
+    impl QueryClient<tonic::transport::Channel> {
+        /// Attempt to create a new client by connecting to a given endpoint.
+        pub async fn connect<D>(dst: D) -> Result<Self, tonic::transport::Error>
+        where
+            D: std::convert::TryInto<tonic::transport::Endpoint>,
+            D::Error: Into<StdError>,
+        {
+            let conn = tonic::transport::Endpoint::new(dst)?.connect().await?;
+            Ok(Self::new(conn))
+        }
+    }
+    impl<T> QueryClient<T>
+    where
+        T: tonic::client::GrpcService<tonic::body::BoxBody>,
+        T::Error: Into<StdError>,
+        T::ResponseBody: Default + Body<Data = prost::bytes::Bytes> + Send + 'static,
+        <T::ResponseBody as Body>::Error: Into<StdError> + Send,
+    {
+        pub fn new(inner: T) -> Self {
+            let inner = tonic::client::Grpc::new(inner);
+            Self { inner }
+        }
+        pub fn with_interceptor<F>(
+            inner: T,
+            interceptor: F,
+        ) -> QueryClient<InterceptedService<T, F>>
+        where
+            F: tonic::service::Interceptor,
+            T: tonic::codegen::Service<
+                http::Request<tonic::body::BoxBody>,
+                Response = http::Response<
+                    <T as tonic::client::GrpcService<tonic::body::BoxBody>>::ResponseBody,
+                >,
+            >,
+            <T as tonic::codegen::Service<
+                http::Request<tonic::body::BoxBody>,
+            >>::Error: Into<StdError> + Send + Sync,
+        {
+            QueryClient::new(InterceptedService::new(inner, interceptor))
+        }
+        /// Compress requests with `gzip`.
+        ///
+        /// This requires the server to support it otherwise it might respond with an
+        /// error.
+        #[must_use]
+        pub fn send_gzip(mut self) -> Self {
+            self.inner = self.inner.send_gzip();
+            self
+        }
+        /// Enable decompressing responses with `gzip`.
+        #[must_use]
+        pub fn accept_gzip(mut self) -> Self {
+            self.inner = self.inner.accept_gzip();
+            self
+        }
+        /// Returns list of `Authorization`, granted to the grantee by the granter.
+        pub async fn grants(
+            &mut self,
+            request: impl tonic::IntoRequest<super::QueryGrantsRequest>,
+        ) -> Result<tonic::Response<super::QueryGrantsResponse>, tonic::Status> {
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
+            let codec = tonic::codec::ProstCodec::default();
+            let path = http::uri::PathAndQuery::from_static(
+                "/cosmos.authz.v1beta1.Query/Grants",
+            );
+            self.inner.unary(request.into_request(), path, codec).await
+        }
+    }
+}
 /// MsgGrant is a request type for Grant method. It declares authorization to the grantee
 /// on behalf of the granter with the provided expiration time.
 #[derive(Clone, PartialEq, ::prost::Message)]
@@ -129,7 +242,7 @@ pub mod msg_client {
     where
         T: tonic::client::GrpcService<tonic::body::BoxBody>,
         T::Error: Into<StdError>,
-        T::ResponseBody: Default + Body<Data = Bytes> + Send + 'static,
+        T::ResponseBody: Default + Body<Data = prost::bytes::Bytes> + Send + 'static,
         <T::ResponseBody as Body>::Error: Into<StdError> + Send,
     {
         pub fn new(inner: T) -> Self {
@@ -237,201 +350,3 @@ pub mod msg_client {
         }
     }
 }
-/// GenesisState defines the authz module's genesis state.
-#[derive(Clone, PartialEq, ::prost::Message)]
-pub struct GenesisState {
-    #[prost(message, repeated, tag="1")]
-    pub authorization: ::prost::alloc::vec::Vec<GrantAuthorization>,
-}
-/// QueryGrantsRequest is the request type for the Query/Grants RPC method.
-#[derive(Clone, PartialEq, ::prost::Message)]
-pub struct QueryGrantsRequest {
-    #[prost(string, tag="1")]
-    pub granter: ::prost::alloc::string::String,
-    #[prost(string, tag="2")]
-    pub grantee: ::prost::alloc::string::String,
-    /// Optional, msg_type_url, when set, will query only grants matching given msg type.
-    #[prost(string, tag="3")]
-    pub msg_type_url: ::prost::alloc::string::String,
-    /// pagination defines an pagination for the request.
-    #[prost(message, optional, tag="4")]
-    pub pagination: ::core::option::Option<super::super::base::query::v1beta1::PageRequest>,
-}
-/// QueryGrantsResponse is the response type for the Query/Authorizations RPC method.
-#[derive(Clone, PartialEq, ::prost::Message)]
-pub struct QueryGrantsResponse {
-    /// authorizations is a list of grants granted for grantee by granter.
-    #[prost(message, repeated, tag="1")]
-    pub grants: ::prost::alloc::vec::Vec<Grant>,
-    /// pagination defines an pagination for the response.
-    #[prost(message, optional, tag="2")]
-    pub pagination: ::core::option::Option<super::super::base::query::v1beta1::PageResponse>,
-}
-/// QueryGranterGrantsRequest is the request type for the Query/GranterGrants RPC method.
-#[derive(Clone, PartialEq, ::prost::Message)]
-pub struct QueryGranterGrantsRequest {
-    #[prost(string, tag="1")]
-    pub granter: ::prost::alloc::string::String,
-    /// pagination defines an pagination for the request.
-    #[prost(message, optional, tag="2")]
-    pub pagination: ::core::option::Option<super::super::base::query::v1beta1::PageRequest>,
-}
-/// QueryGranterGrantsResponse is the response type for the Query/GranterGrants RPC method.
-#[derive(Clone, PartialEq, ::prost::Message)]
-pub struct QueryGranterGrantsResponse {
-    /// grants is a list of grants granted by the granter.
-    #[prost(message, repeated, tag="1")]
-    pub grants: ::prost::alloc::vec::Vec<GrantAuthorization>,
-    /// pagination defines an pagination for the response.
-    #[prost(message, optional, tag="2")]
-    pub pagination: ::core::option::Option<super::super::base::query::v1beta1::PageResponse>,
-}
-/// QueryGranteeGrantsRequest is the request type for the Query/IssuedGrants RPC method.
-#[derive(Clone, PartialEq, ::prost::Message)]
-pub struct QueryGranteeGrantsRequest {
-    #[prost(string, tag="1")]
-    pub grantee: ::prost::alloc::string::String,
-    /// pagination defines an pagination for the request.
-    #[prost(message, optional, tag="2")]
-    pub pagination: ::core::option::Option<super::super::base::query::v1beta1::PageRequest>,
-}
-/// QueryGranteeGrantsResponse is the response type for the Query/GranteeGrants RPC method.
-#[derive(Clone, PartialEq, ::prost::Message)]
-pub struct QueryGranteeGrantsResponse {
-    /// grants is a list of grants granted to the grantee.
-    #[prost(message, repeated, tag="1")]
-    pub grants: ::prost::alloc::vec::Vec<GrantAuthorization>,
-    /// pagination defines an pagination for the response.
-    #[prost(message, optional, tag="2")]
-    pub pagination: ::core::option::Option<super::super::base::query::v1beta1::PageResponse>,
-}
-/// Generated client implementations.
-pub mod query_client {
-    #![allow(unused_variables, dead_code, missing_docs, clippy::let_unit_value)]
-    use tonic::codegen::*;
-    /// Query defines the gRPC querier service.
-    #[derive(Debug, Clone)]
-    pub struct QueryClient<T> {
-        inner: tonic::client::Grpc<T>,
-    }
-    impl QueryClient<tonic::transport::Channel> {
-        /// Attempt to create a new client by connecting to a given endpoint.
-        pub async fn connect<D>(dst: D) -> Result<Self, tonic::transport::Error>
-        where
-            D: std::convert::TryInto<tonic::transport::Endpoint>,
-            D::Error: Into<StdError>,
-        {
-            let conn = tonic::transport::Endpoint::new(dst)?.connect().await?;
-            Ok(Self::new(conn))
-        }
-    }
-    impl<T> QueryClient<T>
-    where
-        T: tonic::client::GrpcService<tonic::body::BoxBody>,
-        T::Error: Into<StdError>,
-        T::ResponseBody: Default + Body<Data = Bytes> + Send + 'static,
-        <T::ResponseBody as Body>::Error: Into<StdError> + Send,
-    {
-        pub fn new(inner: T) -> Self {
-            let inner = tonic::client::Grpc::new(inner);
-            Self { inner }
-        }
-        pub fn with_interceptor<F>(
-            inner: T,
-            interceptor: F,
-        ) -> QueryClient<InterceptedService<T, F>>
-        where
-            F: tonic::service::Interceptor,
-            T: tonic::codegen::Service<
-                http::Request<tonic::body::BoxBody>,
-                Response = http::Response<
-                    <T as tonic::client::GrpcService<tonic::body::BoxBody>>::ResponseBody,
-                >,
-            >,
-            <T as tonic::codegen::Service<
-                http::Request<tonic::body::BoxBody>,
-            >>::Error: Into<StdError> + Send + Sync,
-        {
-            QueryClient::new(InterceptedService::new(inner, interceptor))
-        }
-        /// Compress requests with `gzip`.
-        ///
-        /// This requires the server to support it otherwise it might respond with an
-        /// error.
-        #[must_use]
-        pub fn send_gzip(mut self) -> Self {
-            self.inner = self.inner.send_gzip();
-            self
-        }
-        /// Enable decompressing responses with `gzip`.
-        #[must_use]
-        pub fn accept_gzip(mut self) -> Self {
-            self.inner = self.inner.accept_gzip();
-            self
-        }
-        /// Returns list of `Authorization`, granted to the grantee by the granter.
-        pub async fn grants(
-            &mut self,
-            request: impl tonic::IntoRequest<super::QueryGrantsRequest>,
-        ) -> Result<tonic::Response<super::QueryGrantsResponse>, tonic::Status> {
-            self.inner
-                .ready()
-                .await
-                .map_err(|e| {
-                    tonic::Status::new(
-                        tonic::Code::Unknown,
-                        format!("Service was not ready: {}", e.into()),
-                    )
-                })?;
-            let codec = tonic::codec::ProstCodec::default();
-            let path = http::uri::PathAndQuery::from_static(
-                "/cosmos.authz.v1beta1.Query/Grants",
-            );
-            self.inner.unary(request.into_request(), path, codec).await
-        }
-        /// GranterGrants returns list of `GrantAuthorization`, granted by granter.
-        ///
-        /// Since: cosmos-sdk 0.45.2
-        pub async fn granter_grants(
-            &mut self,
-            request: impl tonic::IntoRequest<super::QueryGranterGrantsRequest>,
-        ) -> Result<tonic::Response<super::QueryGranterGrantsResponse>, tonic::Status> {
-            self.inner
-                .ready()
-                .await
-                .map_err(|e| {
-                    tonic::Status::new(
-                        tonic::Code::Unknown,
-                        format!("Service was not ready: {}", e.into()),
-                    )
-                })?;
-            let codec = tonic::codec::ProstCodec::default();
-            let path = http::uri::PathAndQuery::from_static(
-                "/cosmos.authz.v1beta1.Query/GranterGrants",
-            );
-            self.inner.unary(request.into_request(), path, codec).await
-        }
-        /// GranteeGrants returns a list of `GrantAuthorization` by grantee.
-        ///
-        /// Since: cosmos-sdk 0.45.2
-        pub async fn grantee_grants(
-            &mut self,
-            request: impl tonic::IntoRequest<super::QueryGranteeGrantsRequest>,
-        ) -> Result<tonic::Response<super::QueryGranteeGrantsResponse>, tonic::Status> {
-            self.inner
-                .ready()
-                .await
-                .map_err(|e| {
-                    tonic::Status::new(
-                        tonic::Code::Unknown,
-                        format!("Service was not ready: {}", e.into()),
-                    )
-                })?;
-            let codec = tonic::codec::ProstCodec::default();
-            let path = http::uri::PathAndQuery::from_static(
-                "/cosmos.authz.v1beta1.Query/GranteeGrants",
-            );
-            self.inner.unary(request.into_request(), path, codec).await
-        }
-    }
-}
