@@ -2,65 +2,65 @@
 /// liveness activity.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ValidatorSigningInfo {
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub address: ::prost::alloc::string::String,
     /// Height at which validator was first a candidate OR was unjailed
-    #[prost(int64, tag = "2")]
+    #[prost(int64, tag="2")]
     pub start_height: i64,
     /// Index which is incremented each time the validator was a bonded
     /// in a block and may have signed a precommit or not. This in conjunction with the
     /// `SignedBlocksWindow` param determines the index in the `MissedBlocksBitArray`.
-    #[prost(int64, tag = "3")]
+    #[prost(int64, tag="3")]
     pub index_offset: i64,
     /// Timestamp until which the validator is jailed due to liveness downtime.
-    #[prost(message, optional, tag = "4")]
+    #[prost(message, optional, tag="4")]
     pub jailed_until: ::core::option::Option<::prost_types::Timestamp>,
     /// Whether or not a validator has been tombstoned (killed out of validator set). It is set
     /// once the validator commits an equivocation or for any other configured misbehiavor.
-    #[prost(bool, tag = "5")]
+    #[prost(bool, tag="5")]
     pub tombstoned: bool,
     /// A counter kept to avoid unnecessary array reads.
     /// Note that `Sum(MissedBlocksBitArray)` always equals `MissedBlocksCounter`.
-    #[prost(int64, tag = "6")]
+    #[prost(int64, tag="6")]
     pub missed_blocks_counter: i64,
 }
 /// Params represents the parameters used for by the slashing module.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct Params {
-    #[prost(int64, tag = "1")]
+    #[prost(int64, tag="1")]
     pub signed_blocks_window: i64,
-    #[prost(bytes = "vec", tag = "2")]
+    #[prost(bytes="vec", tag="2")]
     pub min_signed_per_window: ::prost::alloc::vec::Vec<u8>,
-    #[prost(message, optional, tag = "3")]
+    #[prost(message, optional, tag="3")]
     pub downtime_jail_duration: ::core::option::Option<::prost_types::Duration>,
-    #[prost(bytes = "vec", tag = "4")]
+    #[prost(bytes="vec", tag="4")]
     pub slash_fraction_double_sign: ::prost::alloc::vec::Vec<u8>,
-    #[prost(bytes = "vec", tag = "5")]
+    #[prost(bytes="vec", tag="5")]
     pub slash_fraction_downtime: ::prost::alloc::vec::Vec<u8>,
 }
 /// GenesisState defines the slashing module's genesis state.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct GenesisState {
     /// params defines all the paramaters of related to deposit.
-    #[prost(message, optional, tag = "1")]
+    #[prost(message, optional, tag="1")]
     pub params: ::core::option::Option<Params>,
     /// signing_infos represents a map between validator addresses and their
     /// signing infos.
-    #[prost(message, repeated, tag = "2")]
+    #[prost(message, repeated, tag="2")]
     pub signing_infos: ::prost::alloc::vec::Vec<SigningInfo>,
     /// missed_blocks represents a map between validator addresses and their
     /// missed blocks.
-    #[prost(message, repeated, tag = "3")]
+    #[prost(message, repeated, tag="3")]
     pub missed_blocks: ::prost::alloc::vec::Vec<ValidatorMissedBlocks>,
 }
 /// SigningInfo stores validator signing info of corresponding address.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct SigningInfo {
     /// address is the validator address.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub address: ::prost::alloc::string::String,
     /// validator_signing_info represents the signing info of this validator.
-    #[prost(message, optional, tag = "2")]
+    #[prost(message, optional, tag="2")]
     pub validator_signing_info: ::core::option::Option<ValidatorSigningInfo>,
 }
 /// ValidatorMissedBlocks contains array of missed blocks of corresponding
@@ -68,29 +68,30 @@ pub struct SigningInfo {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ValidatorMissedBlocks {
     /// address is the validator address.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub address: ::prost::alloc::string::String,
     /// missed_blocks is an array of missed blocks by the validator.
-    #[prost(message, repeated, tag = "2")]
+    #[prost(message, repeated, tag="2")]
     pub missed_blocks: ::prost::alloc::vec::Vec<MissedBlock>,
 }
 /// MissedBlock contains height and missed status as boolean.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct MissedBlock {
     /// index is the height at which the block was missed.
-    #[prost(int64, tag = "1")]
+    #[prost(int64, tag="1")]
     pub index: i64,
     /// missed is the missed status.
-    #[prost(bool, tag = "2")]
+    #[prost(bool, tag="2")]
     pub missed: bool,
 }
 /// QueryParamsRequest is the request type for the Query/Params RPC method
 #[derive(Clone, PartialEq, ::prost::Message)]
-pub struct QueryParamsRequest {}
+pub struct QueryParamsRequest {
+}
 /// QueryParamsResponse is the response type for the Query/Params RPC method
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct QueryParamsResponse {
-    #[prost(message, optional, tag = "1")]
+    #[prost(message, optional, tag="1")]
     pub params: ::core::option::Option<Params>,
 }
 /// QuerySigningInfoRequest is the request type for the Query/SigningInfo RPC
@@ -98,7 +99,7 @@ pub struct QueryParamsResponse {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct QuerySigningInfoRequest {
     /// cons_address is the address to query signing info of
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub cons_address: ::prost::alloc::string::String,
 }
 /// QuerySigningInfoResponse is the response type for the Query/SigningInfo RPC
@@ -106,14 +107,14 @@ pub struct QuerySigningInfoRequest {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct QuerySigningInfoResponse {
     /// val_signing_info is the signing info of requested val cons address
-    #[prost(message, optional, tag = "1")]
+    #[prost(message, optional, tag="1")]
     pub val_signing_info: ::core::option::Option<ValidatorSigningInfo>,
 }
 /// QuerySigningInfosRequest is the request type for the Query/SigningInfos RPC
 /// method
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct QuerySigningInfosRequest {
-    #[prost(message, optional, tag = "1")]
+    #[prost(message, optional, tag="1")]
     pub pagination: ::core::option::Option<super::super::base::query::v1beta1::PageRequest>,
 }
 /// QuerySigningInfosResponse is the response type for the Query/SigningInfos RPC
@@ -121,24 +122,22 @@ pub struct QuerySigningInfosRequest {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct QuerySigningInfosResponse {
     /// info is the signing info of all validators
-    #[prost(message, repeated, tag = "1")]
+    #[prost(message, repeated, tag="1")]
     pub info: ::prost::alloc::vec::Vec<ValidatorSigningInfo>,
-    #[prost(message, optional, tag = "2")]
+    #[prost(message, optional, tag="2")]
     pub pagination: ::core::option::Option<super::super::base::query::v1beta1::PageResponse>,
 }
-#[cfg(feature = "grpc")]
-#[cfg_attr(docsrs, doc(cfg(feature = "grpc")))]
-#[doc = r" Generated client implementations."]
+/// Generated client implementations.
 pub mod query_client {
     #![allow(unused_variables, dead_code, missing_docs, clippy::let_unit_value)]
     use tonic::codegen::*;
-    #[doc = " Query provides defines the gRPC querier service"]
+    /// Query provides defines the gRPC querier service
     #[derive(Debug, Clone)]
     pub struct QueryClient<T> {
         inner: tonic::client::Grpc<T>,
     }
     impl QueryClient<tonic::transport::Channel> {
-        #[doc = r" Attempt to create a new client by connecting to a given endpoint."]
+        /// Attempt to create a new client by connecting to a given endpoint.
         pub async fn connect<D>(dst: D) -> Result<Self, tonic::transport::Error>
         where
             D: std::convert::TryInto<tonic::transport::Endpoint>,
@@ -151,8 +150,8 @@ pub mod query_client {
     impl<T> QueryClient<T>
     where
         T: tonic::client::GrpcService<tonic::body::BoxBody>,
-        T::ResponseBody: Body + Send + 'static,
         T::Error: Into<StdError>,
+        T::ResponseBody: Default + Body<Data = prost::bytes::Bytes> + Send + 'static,
         <T::ResponseBody as Body>::Error: Into<StdError> + Send,
     {
         pub fn new(inner: T) -> Self {
@@ -171,70 +170,85 @@ pub mod query_client {
                     <T as tonic::client::GrpcService<tonic::body::BoxBody>>::ResponseBody,
                 >,
             >,
-            <T as tonic::codegen::Service<http::Request<tonic::body::BoxBody>>>::Error:
-                Into<StdError> + Send + Sync,
+            <T as tonic::codegen::Service<
+                http::Request<tonic::body::BoxBody>,
+            >>::Error: Into<StdError> + Send + Sync,
         {
             QueryClient::new(InterceptedService::new(inner, interceptor))
         }
-        #[doc = r" Compress requests with `gzip`."]
-        #[doc = r""]
-        #[doc = r" This requires the server to support it otherwise it might respond with an"]
-        #[doc = r" error."]
+        /// Compress requests with `gzip`.
+        ///
+        /// This requires the server to support it otherwise it might respond with an
+        /// error.
+        #[must_use]
         pub fn send_gzip(mut self) -> Self {
             self.inner = self.inner.send_gzip();
             self
         }
-        #[doc = r" Enable decompressing responses with `gzip`."]
+        /// Enable decompressing responses with `gzip`.
+        #[must_use]
         pub fn accept_gzip(mut self) -> Self {
             self.inner = self.inner.accept_gzip();
             self
         }
-        #[doc = " Params queries the parameters of slashing module"]
+        /// Params queries the parameters of slashing module
         pub async fn params(
             &mut self,
             request: impl tonic::IntoRequest<super::QueryParamsRequest>,
         ) -> Result<tonic::Response<super::QueryParamsResponse>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
-            let path =
-                http::uri::PathAndQuery::from_static("/cosmos.slashing.v1beta1.Query/Params");
+            let path = http::uri::PathAndQuery::from_static(
+                "/cosmos.slashing.v1beta1.Query/Params",
+            );
             self.inner.unary(request.into_request(), path, codec).await
         }
-        #[doc = " SigningInfo queries the signing info of given cons address"]
+        /// SigningInfo queries the signing info of given cons address
         pub async fn signing_info(
             &mut self,
             request: impl tonic::IntoRequest<super::QuerySigningInfoRequest>,
         ) -> Result<tonic::Response<super::QuerySigningInfoResponse>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
-            let path =
-                http::uri::PathAndQuery::from_static("/cosmos.slashing.v1beta1.Query/SigningInfo");
+            let path = http::uri::PathAndQuery::from_static(
+                "/cosmos.slashing.v1beta1.Query/SigningInfo",
+            );
             self.inner.unary(request.into_request(), path, codec).await
         }
-        #[doc = " SigningInfos queries signing info of all validators"]
+        /// SigningInfos queries signing info of all validators
         pub async fn signing_infos(
             &mut self,
             request: impl tonic::IntoRequest<super::QuerySigningInfosRequest>,
         ) -> Result<tonic::Response<super::QuerySigningInfosResponse>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
-            let path =
-                http::uri::PathAndQuery::from_static("/cosmos.slashing.v1beta1.Query/SigningInfos");
+            let path = http::uri::PathAndQuery::from_static(
+                "/cosmos.slashing.v1beta1.Query/SigningInfos",
+            );
             self.inner.unary(request.into_request(), path, codec).await
         }
     }
@@ -242,25 +256,24 @@ pub mod query_client {
 /// MsgUnjail defines the Msg/Unjail request type
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct MsgUnjail {
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub validator_addr: ::prost::alloc::string::String,
 }
 /// MsgUnjailResponse defines the Msg/Unjail response type
 #[derive(Clone, PartialEq, ::prost::Message)]
-pub struct MsgUnjailResponse {}
-#[cfg(feature = "grpc")]
-#[cfg_attr(docsrs, doc(cfg(feature = "grpc")))]
-#[doc = r" Generated client implementations."]
+pub struct MsgUnjailResponse {
+}
+/// Generated client implementations.
 pub mod msg_client {
     #![allow(unused_variables, dead_code, missing_docs, clippy::let_unit_value)]
     use tonic::codegen::*;
-    #[doc = " Msg defines the slashing Msg service."]
+    /// Msg defines the slashing Msg service.
     #[derive(Debug, Clone)]
     pub struct MsgClient<T> {
         inner: tonic::client::Grpc<T>,
     }
     impl MsgClient<tonic::transport::Channel> {
-        #[doc = r" Attempt to create a new client by connecting to a given endpoint."]
+        /// Attempt to create a new client by connecting to a given endpoint.
         pub async fn connect<D>(dst: D) -> Result<Self, tonic::transport::Error>
         where
             D: std::convert::TryInto<tonic::transport::Endpoint>,
@@ -273,15 +286,18 @@ pub mod msg_client {
     impl<T> MsgClient<T>
     where
         T: tonic::client::GrpcService<tonic::body::BoxBody>,
-        T::ResponseBody: Body + Send + 'static,
         T::Error: Into<StdError>,
+        T::ResponseBody: Default + Body<Data = prost::bytes::Bytes> + Send + 'static,
         <T::ResponseBody as Body>::Error: Into<StdError> + Send,
     {
         pub fn new(inner: T) -> Self {
             let inner = tonic::client::Grpc::new(inner);
             Self { inner }
         }
-        pub fn with_interceptor<F>(inner: T, interceptor: F) -> MsgClient<InterceptedService<T, F>>
+        pub fn with_interceptor<F>(
+            inner: T,
+            interceptor: F,
+        ) -> MsgClient<InterceptedService<T, F>>
         where
             F: tonic::service::Interceptor,
             T: tonic::codegen::Service<
@@ -290,39 +306,47 @@ pub mod msg_client {
                     <T as tonic::client::GrpcService<tonic::body::BoxBody>>::ResponseBody,
                 >,
             >,
-            <T as tonic::codegen::Service<http::Request<tonic::body::BoxBody>>>::Error:
-                Into<StdError> + Send + Sync,
+            <T as tonic::codegen::Service<
+                http::Request<tonic::body::BoxBody>,
+            >>::Error: Into<StdError> + Send + Sync,
         {
             MsgClient::new(InterceptedService::new(inner, interceptor))
         }
-        #[doc = r" Compress requests with `gzip`."]
-        #[doc = r""]
-        #[doc = r" This requires the server to support it otherwise it might respond with an"]
-        #[doc = r" error."]
+        /// Compress requests with `gzip`.
+        ///
+        /// This requires the server to support it otherwise it might respond with an
+        /// error.
+        #[must_use]
         pub fn send_gzip(mut self) -> Self {
             self.inner = self.inner.send_gzip();
             self
         }
-        #[doc = r" Enable decompressing responses with `gzip`."]
+        /// Enable decompressing responses with `gzip`.
+        #[must_use]
         pub fn accept_gzip(mut self) -> Self {
             self.inner = self.inner.accept_gzip();
             self
         }
-        #[doc = " Unjail defines a method for unjailing a jailed validator, thus returning"]
-        #[doc = " them into the bonded validator set, so they can begin receiving provisions"]
-        #[doc = " and rewards again."]
+        /// Unjail defines a method for unjailing a jailed validator, thus returning
+        /// them into the bonded validator set, so they can begin receiving provisions
+        /// and rewards again.
         pub async fn unjail(
             &mut self,
             request: impl tonic::IntoRequest<super::MsgUnjail>,
         ) -> Result<tonic::Response<super::MsgUnjailResponse>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
-            let path = http::uri::PathAndQuery::from_static("/cosmos.slashing.v1beta1.Msg/Unjail");
+            let path = http::uri::PathAndQuery::from_static(
+                "/cosmos.slashing.v1beta1.Msg/Unjail",
+            );
             self.inner.unary(request.into_request(), path, codec).await
         }
     }
